@@ -20,7 +20,7 @@
 
 package App::MtAws::GlacierRequest;
 
-our $VERSION = '0.981';
+our $VERSION = '1.000';
 
 use strict;
 use warnings;
@@ -243,15 +243,12 @@ sub retrieval_download_job
 		'TreeHash for received file %string filename% (full file) does not match. '.
 		'TreeHash reported by server: %reported%, Calculated TreeHash: %calculated%, TreeHash from Journal: %journal_treehash%',
 		calculated => $th, reported => $reported_th, journal_treehash => $journal_treehash, filename => $relfilename;
-		# TODO: better report relative filename
 
 	$reported_th eq $journal_treehash or
 		die exception 'treehash_mismatch_journal' =>
 		'TreeHash for received file %string filename% (full file) does not match TreeHash in journal. '.
 		'TreeHash reported by server: %reported%, Calculated TreeHash: %calculated%, TreeHash from Journal: %journal_treehash%',
 		calculated => $th, reported => $reported_th, journal_treehash => $journal_treehash, filename => $relfilename;
-		# TODO: better report relative filename
-
 
 	return $resp ? 1 : undef;
 }
@@ -313,21 +310,6 @@ sub retrieval_download_to_memory
 	return $resp->content;
 }
 
-# TODO: remove
-sub download_inventory
-{
-	my ($self, $jobid) = @_;
-
-	$jobid||confess;
-
-	$self->{url} = "/$self->{account_id}/vaults/$self->{vault}/jobs/$jobid/output";
-	$self->{method} = 'GET';
-
-	my $resp = $self->perform_lwp();
-	return $resp ? $resp : undef; # $resp->decoded_content is undefined here as content_file used
-}
-
-
 sub create_vault
 {
 	my ($self, $vault_name) = @_;
@@ -374,9 +356,9 @@ sub _sign
 
 	my $now = time();
 
-	$self->{last_request_time} = $now;
+	$self->{last_request_time} = $now;  # we use same timestamp when writing to journal
 
-	my $date8601 = strftime("%Y%m%dT%H%M%SZ", gmtime($now)); # TODO: use same timestamp when writing to journal
+	my $date8601 = strftime("%Y%m%dT%H%M%SZ", gmtime($now));
 	my $datestr = strftime("%Y%m%d", gmtime($now));
 
 
@@ -450,7 +432,7 @@ sub perform_lwp
 
 		my $ua = LWP::UserAgent->new(timeout => $self->{timeout});
 		$ua->protocols_allowed ( [ 'https' ] ) if $self->{protocol} eq 'https'; # Lets hard code this.
-		$ua->agent("mt-aws-glacier/${App::MtAws::VERSION}beta (http://mt-aws.com/) "); # use of App::MtAws::VERSION_MATURITY instead of 'beta' produce warning
+		$ua->agent("mt-aws-glacier/${App::MtAws::VERSION} (http://mt-aws.com/) "); # use of App::MtAws::VERSION_MATURITY produce warning
 		my $req = undef;
 		my $url = $self->{protocol} ."://$self->{host}$self->{url}";
 		$url = $self->{protocol} ."://$ENV{MTGLACIER_FAKE_HOST}$self->{url}" if $ENV{MTGLACIER_FAKE_HOST};
