@@ -20,9 +20,7 @@
 
 package App::MtAws::ParentWorker;
 
-our $VERSION = '0.981';
-
-use lib 'lib';
+our $VERSION = '1.000';
 
 use strict;
 use warnings;
@@ -31,8 +29,6 @@ use App::MtAws::LineProtocol;
 use Carp;
 use POSIX;
 use App::MtAws::Utils;
-use bytes;
-no bytes;
 
 sub new
 {
@@ -97,7 +93,7 @@ sub wait_worker
 
 		delete $task_list->{$taskid};
 		my ($result) = $ft->finish_task($task);
-	
+
 		if ($result eq 'done') {
 			return ($task->{result}, $task->{attachmentref});
 		}
