@@ -20,7 +20,7 @@
 
 package App::MtAws::Utils;
 
-our $VERSION = '0.981';
+our $VERSION = '1.000';
 
 use strict;
 use warnings;
@@ -31,8 +31,7 @@ use Carp;
 use Encode;
 use App::MtAws::Exceptions;
 use LWP::UserAgent;
-use bytes;
-no bytes;
+use bytes ();
 
 require Exporter;
 use base qw/Exporter/;
